module Hermes
  module Api
    module Dmo
      class EntityReservationsController < Hermes::Api::Dmo::ApplicationController

        MUTATE_PARAMS = %i[
           name
           from
           to
           housing_offer_id
           entity_id
        ]

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
          name
          from
          to
          housing_offer_id
          entity_id
          is_active
        ]

        REGEX_PARAMS = %w[
          name
        ]
        
        def mutate_params
          MUTATE_PARAMS
        end 
        
        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          
          paginate(
            index_aggregation,
            each_serializer: @serializer,
            **@options
          )
        end

        def create 
          @instance = @model.new(mutate_valid_params.merge(user_id: @user.id))
          find_and_update_same_instance

          return respond_with_errors(@instance) unless @instance.save
          render(jsonapi: @instance, serializer: @serializer, status: :created)
        end 

        def update
          @instance.assign_attributes(mutate_valid_params.merge(user_id: @user.id))
          find_and_update_same_instance

          super
        end 

        def destroy
          @instance = @model.find(params[:id])
          return render_json_error(:not_found, :instance_not_found) unless @instance
          return render(json: @instance.errors, status: :unprocessable_entity) unless @instance.destroy
  
          render(body: nil, status: :no_content)
        end

        private 

        def find_and_update_same_instance
          found_instance = Hermes::EntityReservation.order_by(created_at: :desc).find_by(
            entity_id: @instance.entity_id, 
            housing_offer_id: @instance.housing_offer_id,
          )

          if found_instance
            @instance = found_instance
            @instance.assign_attributes(mutate_valid_params.merge(user_id: @user.id))
          end  
        end 

      end
    end
  end
end