# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class LessorObjectivesController < Hermes::Api::Dmo::ApplicationController
        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
          ids
          activation_date
          department
          district
          threshold_type
          priority_public
          new_offer
          target_by_typologies
          present_typologies
          realized_by_typologies
          objective_difference_by_typologies
          lessor_id
          operation_name
          agency_id
          lessor_objective_history_ids
        ]

        REGEX_PARAMS = %w[
          department
          district
          threshold_type
        ]

        MUTATE_PARAMS = %i[
          activation_date
          department
          district
          threshold_type
          priority_public
          new_offer
          target_by_typologies
          lessor_id
          operation_name
          agency_id
        ]
        def mutate_params
          MUTATE_PARAMS
        end 

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end

        def user_can_destroy?
          is_writer_and_is_owner = (@instance.user_id.to_s == current_user.id.to_s)
          is_writer_and_is_owner || current_user.has_role?('Superadmin')
        end
      end
    end
  end
end
