module Hermes
  class UntensedArea
    include Hermes::Concerns::CommonFieldsConcern
    
    field :insee_code, type: String 
    field :department, type: String 
    
    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id


    common_indexes :insee_code, :department
    
    after_save :after_save_actions
    after_destroy :after_destroy_actions
    def find_and_update_requests
      concerned_requests = Hermes::HousingRequest.where({"$or" =>
                                                 [{seeked_district_insee_codes: insee_code} ,
                                                  {seeked_departments: department}
                                                 ]})
      concerned_requests.is_untensed_area = true
      concerned_requests.save
    end
    def after_destroy_actions
      UpdateUntensedAreaJob.perform_later(department, insee_code, true)
    end
    def after_save_actions
      if(department_changed? &&department_was )
        UpdateUntensedAreaJob.perform_later(department_was, nil, true)
      end
      if(insee_code_changed? && insee_code_was )
        UpdateUntensedAreaJob.perform_later(nil, insee_code_was, true)
      end
      UpdateUntensedAreaJob.perform_later(department, insee_code, false)
    end
  end
end