require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')


  describe Api::Dmo::ReservationHoldersController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) {create(:user, roles: ['Administrator'])}
    let!(:superadministrateur) {create(:user, auth_roles: ['superadministrateur'])}
    let!(:user) {create(:user)}
    let(:l1) { create(:lessor)}
    let(:l2) { create(:lessor)}
    let(:l3) { create(:lessor)}
    let(:user1) { create(:user, group_ids: [l1.manager_group_id])}
    let(:user2) { create(:user, group_ids: [l2.manager_group_id])}
    let(:user3) { create(:user, group_ids: [l3.manager_group_id])}
    let!(:rh_public) { create(:reservation_holder, name: 'public', public_read: true, siren: ['123456789'])}
    let!(:rh_lessors) { create(:reservation_holder, name: 'lessors', lessors: [l1, l2], siren: ['223456789'])}

    describe 'GET /reservationn_holders/:siren' do
      it 'returns status code 200 with siren' do
        authenticated_header(request, user1)
        get 'show', id: rh_public.siren.first
        expect(response).to have_http_status(200)
        expect(json['data']['id']).to eq(rh_public.id.to_s)
      end

      it 'returns status code 404 with wrong siren' do
        authenticated_header(request, user1)
        get 'show', id: '323456789'
        expect(response).to have_http_status(404)
      end

      it 'returns status code 200 with id' do
        authenticated_header(request, user1)
        get 'show', id: rh_lessors.id
        expect(response).to have_http_status(200)
        expect(json['data']['id']).to eq(rh_lessors.id.to_s)
      end
    end

    describe 'GET /reservationn_holders' do
      it 'returns all for user with access' do
        authenticated_header(request, user1)
        get 'index'
        expect(json['data'].length).to eq(2)
      end

      it 'only return public for user without access' do
        authenticated_header(request, user3)
        get 'index'
        expect(json['data'].length).to eq(1)
      end
    end
  end
end